"""
========================================================================
|                                                                      |
|                       SUSYAI EXAMPLE SCRIPT 05:                      |
|                   COORDINATE SELECTION VIA FUNCTION                  |
|   ----------------------------------------------------------------   |
|                                                                      |
|   SUSY-AI is a powerful, yet simple interface between SUSY           |
|   data and the sklearn Python class. With the classifier that        |
|   comes with SUSY-AI, it allows for predicting of exclusion of a     |
|   datapoint in pMSSM parameterspace via sklearn using a              |
|   pre-trained classifier in only a couple of commands.               |
|                                                                      |
|   Full documentation, and the most recent version of the software    |
|   can be found on the project website                                |
|                                                                      |
|       https://susyai.hepforge.org/                                   |
|                                                                      |
|   If you are using this script scientifically or commercially,       |
|   please reference the following paper                               |
|                                                                      |
|       Sascha Caron, Jong Soo Kim, Krzysztof Rolbiecki, Roberto       |
|       Ruiz de Austri, Bob Stienen, 'The BSM-AI project: SUSY-AI -    |
|       Generalizing LHC limits on Supersymmetry with Machine          |
|       Learning'. arXiv: 1605.02797 [hep-ph]                          |
|                                                                      |
|   For questions about the script, contact                            |
|                                                                      |
|       Bob Stienen <b.stienen@student.ru.nl>                          |
|                                                                      |
========================================================================
"""

from susyai import susyai
import numpy as np

# Define file
# This has to be a list, even though it is just a single file!
files = ['spectrumfiles/spectrum_01.slha']

# Define coorindate selection function
# This function must take a single PYSLHA DOC object as input argument
#   and return a (19,)-shaped NUMPY NDARRAY, containing the coordinates
# Please note this selection is idential to the one preset-1 makes
def csel(spectrum):
	coords = np.zeros(19)
	coords[0] = spectrum.blocks['MSOFT'][1]           # M_1
	coords[1] = spectrum.blocks['MSOFT'][2]           # M_2
	coords[2] = spectrum.blocks['MSOFT'][3]           # M_3
	coords[3] = spectrum.blocks['MSOFT'][31]          # mL1
	coords[4] = spectrum.blocks['MSOFT'][33]          # mL3
	coords[5] = spectrum.blocks['MSOFT'][34]          # me1
	coords[6] = spectrum.blocks['MSOFT'][36]          # me3
	coords[7] = spectrum.blocks['MSOFT'][41]          # mQ1
	coords[8] = spectrum.blocks['MSOFT'][43]          # mQt
	coords[9] = spectrum.blocks['MSOFT'][44]          # mu1
	coords[10] = spectrum.blocks['MSOFT'][46]         # mtR
	coords[11] = spectrum.blocks['MSOFT'][47]         # md1
	coords[12] = spectrum.blocks['MSOFT'][49]         # mbR
	coords[13] = spectrum.blocks['AU'][(3,3)]         # At
	coords[14] = spectrum.blocks['AD'][(3,3)]         # Ab
	coords[15] = spectrum.blocks['AE'][(3,3)]         # Atau
	coords[16] = spectrum.blocks['HMIX'][1]           # mu
	coords[17] = spectrum.blocks['HMIX'][4]           # mA2
	coords[18] = spectrum.blocks['HMIX'][2]           # tanbeta
	return coords


# Creating susyai object
sa = susyai()

# Set the location of the pickle to a valid location before testing
# Loading before prediction removes the need for it during prediction, thus speeding it up
sa.set_pickle_location("pmssm.pkl")
sa.load_pickle()

# Set coordinate selection to already defined function 
sa.set_coordinate_selector(csel)

# Prediction
clas, pred, conf, coords = sa.predict_files(files)

print("classification: ",clas)
print("prediction:     ",pred)
print("confidence:     ",conf)
