"""
========================================================================
|                                                                      |
|                       SUSYAI EXAMPLE SCRIPT 06:                      |
|                     COORDINATE SELECTION VIA LIST                    |
|   ----------------------------------------------------------------   |
|                                                                      |
|   SUSY-AI is a powerful, yet simple interface between SUSY           |
|   data and the sklearn Python class. With the classifier that        |
|   comes with SUSY-AI, it allows for predicting of exclusion of a     |
|   datapoint in pMSSM parameterspace via sklearn using a              |
|   pre-trained classifier in only a couple of commands.               |
|                                                                      |
|   Full documentation, and the most recent version of the software    |
|   can be found on the project website                                |
|                                                                      |
|       https://susyai.hepforge.org/                                   |
|                                                                      |
|   If you are using this script scientifically or commercially,       |
|   please reference the following paper                               |
|                                                                      |
|       Sascha Caron, Jong Soo Kim, Krzysztof Rolbiecki, Roberto       |
|       Ruiz de Austri, Bob Stienen, 'The BSM-AI project: SUSY-AI -    |
|       Generalizing LHC limits on Supersymmetry with Machine          |
|       Learning'. arXiv: 1605.02797 [hep-ph]                          |
|                                                                      |
|   For questions about the script, contact                            |
|                                                                      |
|       Bob Stienen <b.stienen@student.ru.nl>                          |
|                                                                      |
========================================================================
"""

from susyai import susyai
import numpy as np

# Define file
# This has to be a list, even though it is just a single file!
files = ['spectrumfiles/spectrum_01.slha']

# Define coorindate selection list
# Please note that this selection is identical to the one preset-1 makes
selectionlist = [['MSOFT', 1],		# M_1
	['MSOFT', 2],			# M_2
	['MSOFT', 3],			# M_3
	['MSOFT', 31],			# mL1
	['MSOFT', 33],			# mL3
	['MSOFT', 34],			# me1
	['MSOFT', 36],			# me3
	['MSOFT', 41],			# mQ1
	['MSOFT', 43],			# mQt
	['MSOFT', 44],			# mu1
	['MSOFT', 46],			# mtR
	['MSOFT', 47],			# md1
	['MSOFT', 49],			# mbR
	['AU', (3,3)],			# At
	['AD', (3,3)],			# Ab
	['AE', (3,3)],			# Atau
	['HMIX', 1],			# mu
	['HMIX', 4],			# mA2
	['HMIX', 2]]			# tanbeta

# Creating susyai object
sa = susyai()

# Set the location of the pickle to a valid location before testing
# Loading before prediction removes the need for it during prediction, thus speeding it up
sa.set_pickle_location("pmssm.pkl")
sa.load_pickle()

# Set coordinate selection to already defined function 
sa.set_coordinate_selector(selectionlist)

# Prediction
clas, pred, conf, coords = sa.predict_files(files)

print("classification: ",clas)
print("prediction:     ",pred)
print("confidence:     ",conf)
